<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 1/6/2010	ELL
// Revised: 2/10/2012	ELL
// Added table prefix handling.
// 
// 
	include ("check_session.php");
	
	$menu_name = $_POST['selectMenu2'];
	$description = $_POST['new_description'];

	if (($menu_name != "") && isset($menu_name))
	{	
		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '$description' WHERE `menu_name` = '$menu_name'";
		$cnt = $bwb_dbh->exec($query);
	}
	
	header("Location: manage_menu.php?menu=$menu_name");
	
?>
